"""Models."""

from __future__ import annotations

__all__: tuple[str, ...] = (
    "CallDirection",
    "CallID",
    "CallItem",
    "CallResponse",
    "CallScope",
    "CallsResponse",
    "Cursor",
    "EventID",
    "MediaType",
    "RecordsInfo",
    "RequestID",
    "StrID",
    "UserID",
    "WorkspaceID",
)


from datetime import datetime, timedelta  # noqa: TC003
from enum import Enum

from pydantic import BaseModel, ConfigDict, HttpUrl

type StrID = str

type WorkspaceID = StrID
type RequestID = StrID
type CallID = StrID
type UserID = StrID
type EventID = StrID
type Cursor = str


def to_camel(s: str) -> str:
    """snake_case -> camelCase."""
    parts = s.split("_")
    return parts[0] + "".join(p.capitalize() for p in parts[1:])


class CallDirection(str, Enum):
    """Call direction."""

    INBOUND = "Inbound"
    OUTBOUND = "Outbound"
    CONFERENCE = "Conference"
    UNKNOWN = "Unknown"


class CallScope(str, Enum):
    """Scope of the call."""

    INTERNAL = "Internal"
    EXTERNAL = "External"
    UNKNOWN = "Unknown"


class MediaType(str, Enum):
    """Media type of the call recording."""

    VIDEO = "Video"
    AUDIO = "Audio"


class RecordsInfo(BaseModel):
    """Information about the number of records that match the requested filter."""

    model_config = ConfigDict(populate_by_name=True, alias_generator=to_camel)

    total_records: int
    """Total number of records."""

    current_page_size: int
    """Number of records in the current page."""

    current_page_number: int
    """Current page number."""

    cursor: Cursor | None = None
    """Pagination cursor. Returned only when there are more records to be retrieved.
    Pass this value in the next request to fetch the next page."""


class CallItem(BaseModel):
    """One call entry."""

    model_config = ConfigDict(populate_by_name=True, alias_generator=to_camel)

    id: CallID
    """Gong's unique numeric identifier for the call (up to 20 digits)."""

    url: HttpUrl
    """URL to the call page in the Gong web application."""

    title: str
    """The title of the call."""

    scheduled: datetime
    """Scheduled date and time of the call (ISO-8601)."""

    started: datetime
    """Date and time when the call was recorded (ISO-8601)."""

    duration: timedelta
    """Duration of the call in seconds."""

    primary_user_id: UserID
    """Primary user ID of the team member who hosted the call."""

    direction: CallDirection
    """Call direction. Allowed values: Inbound, Outbound, Conference, Unknown."""

    system: str
    """System with which the call was carried out (e.g., WebEx, ShoreTel)."""

    scope: CallScope
    """Scope of the call: 'internal', 'external', or 'unknown'."""

    media: MediaType
    """Media type. Allowed values: Video, Audio."""

    language: str
    """Language code (ISO-639-2B), e.g., 'eng', 'fre', 'spa', 'ger', 'ita'.
    Also: 'und', 'zxx'."""

    workspace_id: WorkspaceID
    """Gong's unique numeric identifier for the call's workspace (up to 20 digits)."""

    sdr_disposition: str | None = None
    """SDR disposition of the call—automatically provided or manually entered."""

    client_unique_id: StrID | None = None
    """Call's unique ID in the origin recording system."""

    custom_data: str | None = None
    """Custom metadata provided during call creation."""

    purpose: str | None = None
    """Purpose of the call."""

    meeting_url: HttpUrl | None = None
    """Meeting provider URL where the web conference was recorded."""

    is_private: bool
    """Whether the call is private."""

    calendar_event_id: EventID | None = None
    """ID of the associated Google or Outlook Calendar event."""


class CallsResponse(BaseModel):
    """Calls."""

    model_config = ConfigDict(populate_by_name=True, alias_generator=to_camel)

    request_id: RequestID
    """A Gong request reference ID generated for this request.
    Use for troubleshooting."""

    records: RecordsInfo
    """Information about the number of records that match the requested filter."""

    calls: list[CallItem]
    """A list in which each item specifies one call."""


class CallResponse(BaseModel):
    """Call."""

    model_config = ConfigDict(populate_by_name=True, alias_generator=to_camel)

    request_id: RequestID
    """A Gong request reference ID generated for this request.
    Use for troubleshooting."""

    call: CallItem
    """Call."""



"""Configuration file for the Sphinx documentation builder."""

# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.

import importlib.util
import sys
from pathlib import Path

sys.path.insert(0, str(Path("..").resolve()))


# -- Project information -----------------------------------------------------

project = "Gongy"
copyright = "2025, Micael Jarniac"  # noqa: A001
author = "Micael Jarniac"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.napoleon",
    "sphinx.ext.doctest",
    "sphinx.ext.intersphinx",
    "sphinx.ext.autosummary",
    "sphinx.ext.viewcode",
    "myst_parser",
]

maybe_extensions = [
    "sphinxcontrib.spelling",
]

for extension in maybe_extensions:
    lib = importlib.util.find_spec(extension)
    if lib is not None:
        extensions.append(lib.name)

spelling_word_list_filename = "wordlist.txt"

# make spelling

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]

source_suffix = [".rst", ".md"]


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "furo"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]
